@@ -22,18 +22,25 @@ import javax.faces.context.FacesContext;
 import javax.faces.event.PhaseId;
 
 /**
- * Implements the lifecycle as described in Spec. 1.0 PFD Chapter 2
- * @author Nikolay Petrov
- *
- * Apply request values phase (JSF Spec 2.2.2)
+ * Implements the apply request values phase (JSF Spec 2.2.2)
+ * 
+ * @author Nikolay Petrov (latest modification by $Author$)
+ * @version $Revision$ $Date$
  */
-class ApplyRequestValuesExecutor implements PhaseExecutor {
-    public boolean execute(FacesContext facesContext) {
+class ApplyRequestValuesExecutor extends PhaseExecutor
+{
+    public boolean execute(FacesContext facesContext)
+    {
+        if (facesContext.getViewRoot() == null)
+        {
+            throw new ViewNotFoundException("A view is required to execute "+facesContext.getCurrentPhaseId());
+        }
         facesContext.getViewRoot().processDecodes(facesContext);
         return false;
     }
 
-    public PhaseId getPhase() {
+    public PhaseId getPhase()
+    {
         return PhaseId.APPLY_REQUEST_VALUES;
     }
 }
